@@ -9,9 +9,8 @@
 #' @rdname Operand
 setGeneric(
   "Operand",
-  function(object, value) {},
-  valueClass = ".operand",
-  useAsDefault = FALSE
+  function(object, value) {standardGeneric("Operand")},
+  valueClass = ".operand"
 )
 
 #' Operand<-.
@@ -28,3 +27,4 @@ setGeneric(
     object
   }
 )
+
